Structs
- Appender
Builder - Builder for adding appenders to a format
Fn. - Builder
- Builder for configuring
trivial_log. Usetrivial_log::builder()to obtain a new instance of this struct.
Enums
Traits
- Appender
- This trait defines an appender which consumes a formatted log message of type T and will “write” it to somewhere like stdout/disk/network/…
- Into
Appender - Custom “Into” trait that produces an Arc<dyn
Appender<T>. This trait does not usually need to implemented manually. It is implemented for all Appender structs by default.
Functions
- builder
- free
- This fn will remove all formats and appenders from the log impl making it essentially a noop.
- init_
std - Initializes
logto forward all warn and below to stdout and all error to stderr - init_
stderr - Initializes
logto forward all log to stderr using the default format - init_
stdout - Initializes
logto forward all log to stdout using the default format